CALCEPH Library Copying conditions — CALCEPH - C language 3.4.1 documentation

# CALCEPH Library Copying conditions

Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019,

CNRS, Observatoire de Paris, Observatoire de la Côte d'Azur

Contributed by

Gastineau M. , Laskar J., Manche H., Astronomie et Systèmes Dynamiques, IMCCE, CNRS, Observatoire de Paris, UPMC

Fienga A. , Observatoire de la Côte d'Azur

inpop.imcce@obspm.fr

This library is governed by the CeCILL-C,CeCILL-B or CeCILL version 2 license under French law and abiding by the rules of distribution of free software. You can use, modify and/ or redistribute the software under the terms of the CeCILL-C,CeCILL-B or CeCILL version 2 license as circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".

As a counterpart to the access to the source code and rights to copy, modify and redistribute granted by the license, users are provided only with a limited warranty and the software's author, the holder of the economic rights, and the successive licensors have only limited liability.

In this respect, the user's attention is drawn to the risks associated with loading, using, modifying and/or developing or reproducing the software by the user in light of its specific status of free software, that may mean that it is complicated to manipulate, and that also therefore means that it is reserved for developers and experienced professionals having in-depth computer knowledge. Users are therefore encouraged to load and test the software's suitability as regards their requirements in conditions enabling the security of their systems and/or data to be ensured and, more generally, to use and operate it in the same conditions as regards security.

The fact that you are presently reading this means that you have had knowledge of the CeCILL-C,CeCILL-B or CeCILL version 2 license and that you accept its terms.